@@ -1,9 +1,7 @@
-# -*- python -*-
-# -*- coding: utf-8 -*-
 #
 #  This file is part of the easydev software
 #
-#  Copyright (c) 2011-2017
+#  Copyright (c) 2011-2020
 #
 #  File author(s): Thomas Cokelaer <cokelaer@gmail.com>
 #
@@ -21,12 +19,22 @@ import json
 import os
 import sys
 
-__all__ = ["shellcmd", "swapdict", "check_param_in_list",
-    "check_range", "precision", "AttrDict", "DevTools", "execute",
-    "touch", "mkdirs"]
+
+__all__ = [
+    "shellcmd",
+    "swapdict",
+    "check_param_in_list",
+    "check_range",
+    "precision",
+    "AttrDict",
+    "DevTools",
+    "execute",
+    "touch",
+    "mkdirs",
+]
 
 
-def precision(data, digit=2): 
+def precision(data, digit=2):
     """Round values in a list keeping only N digits precision
 
     ::
@@ -37,8 +45,8 @@ def precision(data, digit=2):
         2100
 
     """
-    data = int(data*pow(10, digit))
-    data /= pow(10., digit)
+    data = int(data * pow(10, digit))
+    data /= pow(10.0, digit)
     return data
 
 
@@ -89,7 +97,11 @@ def check_param_in_list(param, valid_values, name=None):
     """
     if isinstance(valid_values, list) is False:
 
-        raise TypeError("the valid_values second argument must be a list of valid values. {0} was provided.".format(valid_values))
+        raise TypeError(
+            "the valid_values second argument must be a list of valid values. {0} was provided.".format(
+                valid_values
+            )
+        )
 
     if param not in valid_values:
         if name:
@@ -114,8 +126,9 @@ def shellcmd(cmd, show=False, verbose=False, ignore_errors=False):
     if show:
         print(cmd)
     try:
-        ret = subprocess.Popen([cmd], stdout=subprocess.PIPE,
-            stderr=subprocess.PIPE, shell=True)
+        ret = subprocess.Popen(
+            [cmd], stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True
+        )
 
         output = ret.stdout.read().strip()
         error = ret.stderr.read().strip()
@@ -144,6 +157,7 @@ def execute(cmd, showcmd=True, verbose=True):
     :param verbose:
     """
     import pexpect
+
     if showcmd is True:
         print(cmd)
 
@@ -161,10 +175,8 @@ def execute(cmd, showcmd=True, verbose=True):
 
 
 def touch(fname, times=None):
-    """Touch a file (like unix command)
-
-    """
-    with open(fname, 'a'):
+    """Touch a file (like unix command)"""
+    with open(fname, "a"):
         os.utime(fname, times)
 
 
@@ -180,7 +192,9 @@ def swapdict(dic, check_ambiguity=True):
     """
     # this version is more elegant but slightly slower : return {v:k for k,v in dic.items()}
     if check_ambiguity:
-        assert len(set(dic.keys())) == len(set(dic.values())), "values is not a set. ambiguities for keys."
+        assert len(set(dic.keys())) == len(
+            set(dic.values())
+        ), "values is not a set. ambiguities for keys."
     return dict(zip(dic.values(), dic.keys()))
 
 
@@ -207,10 +221,12 @@ def mkdirs(newdir, mode=0o777):
                     os.makedirs(thispart, mode)
     except OSError as err:
         import errno
+
         # Reraise the error unless it's about an already existing directory
         if err.errno != errno.EEXIST or not os.path.isdir(newdir):
             raise
 
+
 class AttrDict(dict):
     """dictionary-like object that exposes its keys as attributes.
 
@@ -260,6 +276,7 @@ class AttrDict(dict):
     then *a* is indeed a dictionary.
 
     """
+
     def __init__(self, **kwargs):
         dict.__init__(self, kwargs)
         self.__dict__ = self
@@ -291,11 +308,12 @@ class AttrDict(dict):
         does not remove existing keys put replace them if already present
         """
         res = json.load(open(filename, "r"))
-        for k,v in res.items():
+        for k, v in res.items():
             self[k] = v
 
     def to_json(self, filename=None):
         import json
+
         if filename is not None:
             with open(filename, "w") as fout:
                 json.dump(self, fout)
@@ -304,9 +322,8 @@ class AttrDict(dict):
 
 
 class DevTools(object):
-    """Aggregate of easydev.tools functions.
+    """Aggregate of easydev.tools functions."""
 
-    """
     def check_range(self, value, a, b):
         """wrapper around :func:`easydev.check_range`"""
         check_range(value, a, b, strict=False)
@@ -328,6 +345,7 @@ class DevTools(object):
         1 -> [1]
         """
         from easydev import codecs
+
         return codecs.to_list(query)
 
     def list2string(self, query, sep=",", space=False):
@@ -336,6 +354,7 @@ class DevTools(object):
 
         """
         from easydev import codecs
+
         return codecs.list2string(query, sep=sep, space=space)
 
     def to_json(self, dictionary):
@@ -347,9 +366,9 @@ class DevTools(object):
         try:
             os.mkdir(dirname)
         except OSError:
-            pass # exists already
+            pass  # exists already
         except Exception as err:
-            raise(err)
+            raise (err)
 
     def shellcmd(self, cmd, show=False, verbose=False, ignore_errors=False):
         """See :func:`shellcmd`"""
@@ -362,7 +381,3 @@ class DevTools(object):
 
     def mkdirs(self, dirname, mode=0o777):
         mkdirs(dirname, mode=mode)
-
-
-
-
